@@ -46,7 +46,13 @@ def _get_one_segment(googleanalytics, report, all_view_id, start, end, time_incr
             metric_filter,
             dimension_filter,
             segment)
-        view_result, view_all_batch_id = create_columns_rows(data, view_id, time_increment, types)
+        view_result, view_all_batch_id = create_columns_rows(
+            googleanalytics=googleanalytics,
+            data=data,
+            view_id=view_id,
+            time_increment=time_increment,
+            types=types
+        )
         if result.get("columns_name") is None or (len(view_result["columns_name"]) > len(result["columns_name"])):
             result["columns_name"] = view_result["columns_name"]
         result["types"] = view_result["types"]
@@ -101,6 +107,8 @@ def _get_data_by_segment(googleanalytics, start, end, report, all_view_id, incre
                     except HttpError as error:
                         if error.resp.reason in ["internalServerError", "backendError"]:
                             time.sleep((2 ** n) + random.random())
+                        else:
+                            raise error
                 if i == 0:  # Concatenate to send to spreadsheet
                     result = segment_data
                     i = i + 1
